==> owncloud-8.1.0p2.tgz: owncloud/apps/files_sharing/l10n/sl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Na tem strežniku ni omogočena možnost souporabe strežnika s strežnikom.",
    "The mountpoint name contains invalid characters." : "Ime točke priklopa vsebuje neveljavne znake.",
    "Invalid or untrusted SSL certificate" : "Neveljavno oziroma nepotrjeno potrdilo SSL",
    "Could not authenticate to remote share, password might be wrong" : "Ni mogoče overiti istovetnosti oddaljene mape za souporabo. Najverjetneje je uporabljeno napačno geslo.",
    "Storage not valid" : "Shramba ni veljavna",
    "Couldn't add remote share" : "Ni mogoče dodati oddaljenega mesta za souporabo",
    "Shared with you" : "V souporabi z vami",
    "Shared with others" : "V souporabi  z drugimi",
    "Shared by link" : "Souporaba s povezavo",
    "Nothing shared with you yet" : "Datotek drugih uporabnikov še ni v souporabi",
    "Files and folders others share with you will show up here" : "Datoteke in mape, katerih souporabo z vami dovolijo drugi, bodo izpisane na tem mestu",
    "Nothing shared yet" : "Souporabe datotek še niste omogočili",
    "Files and folders you share will show up here" : "Datoteke in mape, katerih souporabo z drugimi dovolite vi, bodo izpisane na tem mestu",
    "No shared links" : "Ni povezav za souporabo",
    "Files and folders you share by link will show up here" : "Datoteke in mape, katerih souporabo preko povezave z drugimi dovolite vi, bodo izpisane na tem mestu",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ali želite dodati oddaljeno mesto souporabe {name} na {owner}@{remote}?",
    "Remote share" : "Oddaljeno mesto za souporabo",
    "Remote share password" : "Geslo za mesto za oddaljeno souporabo",
    "Cancel" : "Prekliči",
    "Add remote share" : "Dodaj oddaljeno mesto za souporabo",
    "No ownCloud installation (7 or higher) found at {remote}" : "Na mestu {remote} ni nameščenega okolja ownCloud (različice 7 ali višje)",
    "Invalid ownCloud url" : "Naveden je neveljaven naslov URL strežnika ownCloud",
    "Share" : "Souporaba",
    "Shared by" : "V souporabi z",
    "A file or folder has been <strong>shared</strong>" : "Za datoteko ali mapo je odobrena <strong>souporaba</strong>.",
    "A file or folder was shared from <strong>another server</strong>" : "Souporaba datoteke ali mape <strong>z drugega strežnika</strong> je odobrena.",
    "A public shared file or folder was <strong>downloaded</strong>" : "Mapa ali datoteka v souporabi je bila <strong>prejeta</strong>.",
    "You received a new remote share from %s" : "Prejeli ste mapo za oddaljeno souporabo z %s",
    "%1$s accepted remote share %2$s" : "Uporabnik %1$s je prejel oddaljeno souporabo %2$s",
    "%1$s declined remote share %2$s" : "Uporabnik %1$s je zavrnil souporabo %2$s",
    "%1$s unshared %2$s from you" : "Uporabnik %1$s je onemogoči souporabo %2$s z vami",
    "Public shared folder %1$s was downloaded" : "Mapa v souporabi %1$s je bila prejeta",
    "Public shared file %1$s was downloaded" : "Datoteka v souporabi %1$s je bila prejeta",
    "You shared %1$s with %2$s" : "Omogočili ste souporabo %1$s z uporabnikom %2$s",
    "You shared %1$s with group %2$s" : "Omogočili ste souporabo %1$s s skupino %2$s",
    "%2$s shared %1$s with you" : "Uporabnik %2$s je omogočil souporabo %1$s",
    "You shared %1$s via link" : "Omogočili ste souporabo %1$s preko povezave",
    "Shares" : "Souporaba",
    "This share is password-protected" : "To mesto je zaščiteno z geslom.",
    "The password is wrong. Try again." : "Geslo je napačno. Poskusite znova.",
    "Password" : "Geslo",
    "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
    "Name" : "Ime",
    "Share time" : "Čas souporabe",
    "Sorry, this link doesn’t seem to work anymore." : "Povezava očitno ni več v uporabi.",
    "Reasons might be:" : "Vzrok je lahko:",
    "the item was removed" : "predmet je odstranjen,",
    "the link expired" : "povezava je pretekla,",
    "sharing is disabled" : "souporaba je onemogočena.",
    "For more info, please ask the person who sent this link." : "Za več podrobnosti stopite v stik s pošiljateljem te povezave.",
    "Add to your ownCloud" : "Dodaj v svoj oblak ownCloud",
    "Download" : "Prejmi",
    "Download %s" : "Prejmi %s",
    "Direct link" : "Neposredna povezava",
    "Federated Cloud Sharing" : "Upravljana souporaba oblaka",
    "Open documentation" : "Odpri dokumentacijo",
    "Allow users on this server to send shares to other servers" : "Dovoli uporabnikom tega strežnika pošiljanje map za souporabo na druge strežnike.",
    "Allow users on this server to receive shares from other servers" : "Dovoli uporabnikom tega strežnika sprejemanje map za souporabo z drugih strežnikov.",
    "HTML Code:" : "Koda HTML:"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> owncloud-8.2.2p3.tgz: owncloud/apps/files_sharing/l10n/sl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Na tem strežniku ni omogočena možnost souporabe strežnika s strežnikom.",
    "The mountpoint name contains invalid characters." : "Ime točke priklopa vsebuje neveljavne znake.",
    "Invalid or untrusted SSL certificate" : "Neveljavno oziroma nepotrjeno potrdilo SSL",
    "Could not authenticate to remote share, password might be wrong" : "Ni mogoče overiti istovetnosti oddaljene mape za souporabo. Najverjetneje je uporabljeno napačno geslo.",
    "Storage not valid" : "Shramba ni veljavna",
    "Couldn't add remote share" : "Ni mogoče dodati oddaljenega mesta za souporabo",
    "Shared with you" : "V souporabi z vami",
    "Shared with others" : "V souporabi  z drugimi",
    "Shared by link" : "Souporaba s povezavo",
    "Nothing shared with you yet" : "Datotek drugih uporabnikov še ni v souporabi",
    "Files and folders others share with you will show up here" : "Datoteke in mape, katerih souporabo z vami dovolijo drugi, bodo izpisane na tem mestu",
    "Nothing shared yet" : "Souporabe datotek še niste omogočili",
    "Files and folders you share will show up here" : "Datoteke in mape, katerih souporabo z drugimi dovolite vi, bodo izpisane na tem mestu",
    "No shared links" : "Ni povezav za souporabo",
    "Files and folders you share by link will show up here" : "Datoteke in mape, katerih souporabo preko povezave z drugimi dovolite vi, bodo izpisane na tem mestu",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ali želite dodati oddaljeno mesto souporabe {name} na {owner}@{remote}?",
    "Remote share" : "Oddaljeno mesto za souporabo",
    "Remote share password" : "Geslo za mesto za oddaljeno souporabo",
    "Cancel" : "Prekliči",
    "Add remote share" : "Dodaj oddaljeno mesto za souporabo",
    "No ownCloud installation (7 or higher) found at {remote}" : "Na mestu {remote} ni nameščenega okolja ownCloud (različice 7 ali višje)",
    "Invalid ownCloud url" : "Naveden je neveljaven naslov URL strežnika ownCloud",
    "Shared by" : "V souporabi z",
    "Sharing" : "Souporaba",
    "A file or folder has been <strong>shared</strong>" : "Za datoteko ali mapo je odobrena <strong>souporaba</strong>.",
    "A file or folder was shared from <strong>another server</strong>" : "Souporaba datoteke ali mape <strong>z drugega strežnika</strong> je odobrena.",
    "A public shared file or folder was <strong>downloaded</strong>" : "Mapa ali datoteka v souporabi je bila <strong>prejeta</strong>.",
    "You received a new remote share from %s" : "Prejeli ste mapo za oddaljeno souporabo z %s",
    "%1$s accepted remote share %2$s" : "Uporabnik %1$s je prejel oddaljeno souporabo %2$s",
    "%1$s declined remote share %2$s" : "Uporabnik %1$s je zavrnil souporabo %2$s",
    "%1$s unshared %2$s from you" : "Uporabnik %1$s je onemogoči souporabo %2$s z vami",
    "Public shared folder %1$s was downloaded" : "Mapa v souporabi %1$s je bila prejeta",
    "Public shared file %1$s was downloaded" : "Datoteka v souporabi %1$s je bila prejeta",
    "You shared %1$s with %2$s" : "Omogočili ste souporabo %1$s z uporabnikom %2$s",
    "You shared %1$s with group %2$s" : "Omogočili ste souporabo %1$s s skupino %2$s",
    "%2$s shared %1$s with you" : "Uporabnik %2$s je omogočil souporabo %1$s",
    "You shared %1$s via link" : "Omogočili ste souporabo %1$s preko povezave",
    "Shares" : "Souporaba",
    "Accept" : "Sprejmi",
    "This share is password-protected" : "To mesto je zaščiteno z geslom.",
    "The password is wrong. Try again." : "Geslo je napačno. Poskusite znova.",
    "Password" : "Geslo",
    "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
    "Name" : "Ime",
    "Share time" : "Čas souporabe",
    "Sorry, this link doesn’t seem to work anymore." : "Povezava očitno ni več v uporabi.",
    "Reasons might be:" : "Vzrok je lahko:",
    "the item was removed" : "predmet je odstranjen,",
    "the link expired" : "povezava je pretekla,",
    "sharing is disabled" : "souporaba je onemogočena.",
    "For more info, please ask the person who sent this link." : "Za več podrobnosti stopite v stik s pošiljateljem te povezave.",
    "Add to your ownCloud" : "Dodaj v svoj oblak ownCloud",
    "Download" : "Prejmi",
    "Download %s" : "Prejmi %s",
    "Direct link" : "Neposredna povezava",
    "Federated Cloud Sharing" : "Upravljana souporaba oblaka",
    "Open documentation" : "Odpri dokumentacijo",
    "Allow users on this server to send shares to other servers" : "Dovoli uporabnikom tega strežnika pošiljanje map za souporabo na druge strežnike.",
    "Allow users on this server to receive shares from other servers" : "Dovoli uporabnikom tega strežnika sprejemanje map za souporabo z drugih strežnikov.",
    "HTML Code:" : "Koda HTML:"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
